This function is a wrapper for the rm() function.
This function takes a pattern, which can include a wildcard (*, asterisk)
in either the argument remove or keep to either remove or keep
all objects matching a string.
It's possible to input multiple variable names in the remove argument,
but it's not (yet) possible for the 'keep' argument.
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.